Change log
==========

0.4
---

* Updated GOV.UK dependency versions

0.3
---

* Added JS files from GOV.UK elements and front-end toolkit
* Minor accessibility and visual improvements

0.2
---

* Added a model to control header and footer content
* Added gettext message compilation
* Added pagination components

0.1
---

* Initial version, loads GOV.UK template, elements and front-end toolkit components (HTML and SCSS files)
* Can pre-build SCSS files if libsass is installed
